{********************************************************}
{* Stream TEST - MIDAS/FPC sample program               *}
{*                                                      *}
{* This is a little sample program showing how to use   *}
{* playback streams with MIDAS/FPC                      *}
{*                                                      *}
{* Problems compiling this program? Read the file       *}
{* install.htm in the MIDAS/FPC package!                *}
{*                                                      *}
{* Copyright (C) 1999 Udo Giacomozzi                    *}
{* homepage: http://come.to/jampy                       *}
{* e-mail: ugcm@usa.net                                 *}
{********************************************************}

program StreamTest;

{$MODE Delphi}

uses crt,midasdll;

procedure MIDASerror;
var
  ErrNo : LongInt;
begin
    Write('*** MIDAS error #');
    ErrNo:=MIDASgetLastError;
    write(ErrNo,': ');
    writeln('  ', MIDASgetErrorMessage(ErrNo));
    If ErrNo<>0 then
    begin
      MIDASclose;
      halt;
    end else begin
      writeln('Press ENTER...');
      ReadLn;
    end;
end;

procedure CheckError;
var
  ErrNo : LongInt;
begin
  ErrNo:=MIDASgetLastError;
  If ErrNo<>0 then
  begin
    Write('*** MIDAS error #');
    write(ErrNo,': ');
    writeln('  ', MIDASgetErrorMessage(ErrNo));
    MIDASclose;
  end;
end;


type
    tBufferType = SmallInt;

var
    stream : MIDASstreamhandle;
    i : Integer;
    Buffer : Array[1..1024] of tBufferType;
    c : LongInt;

BEGIN
    if SizeOf(tBufferType)<>2 then
    begin
      writeln('Wrong buffer sample type. Has to be 16-bit integer!');
      Halt;
    end;

    writeln('MIDASstartup');
    MIDASstartup;
    CheckError;

    writeln('MIDASconfig');
    if not MIDASconfig then
    BEGIN
      writeln('Config failed!');
      MIDASerror;
    END;

    writeln('MIDASinit');
    if not MIDASinit then
        MIDASerror;

    writeln('Version: ',MidasGetVersionString);

    writeln('MIDASstartBackgroundPlay(0)');
    if not MIDASstartBackgroundPlay(0) then
        MIDASerror;


    {--------------}

    writeln('Opening 1 channel...');
    If not MIDASopenChannels(1) then MIDASerror;

    writeln('Opening stream...');
    stream:=MIDASplayStreamPolling(MIDAS_SAMPLE_16BIT_STEREO,
                                   44100, // Hz
                                   200);  // ms

    writeln('DWORD(stream) = ',DWORD(stream));
    If stream=nil then
    begin
      writeln('MIDASplayStreamPolling returned NIL!');
      MIDASerror;
    end;

    writeln;
    writeln('Stream opened successfully in polling mode. Playback will start');
    writeln('when enough sound data is contained in the stream buffer.');
    writeln('Hit any key to stop playback!');

    repeat
      write('.');
      For i:=Low(Buffer) to High(Buffer) do
      begin
        Inc(c);
        Buffer[i]:=Round( Sin(c/20) *15000);
      end;

      MIDASfeedStreamData(stream, @Buffer, SizeOf(Buffer), true);
    until keypressed;

    writeln;
    writeln('Playback stopped (no more data is being feeded to the stream).');


    writeln('Stopping stream...');
    If not MIDASstopStream(stream) then midaserror;


    {--------------}


    if not MIDASstopBackgroundPlay then
        MIDASerror;
    if not MIDASclose then
        MIDASerror;

  writeln('PROGRAM TERMINATED.');
END.